==> kubernetes-model-networking-5.10.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LoadBalancerStatus;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class IngressStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.IngressStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.IngressStatusFluent<A>{
  public IngressStatusFluentImpl() {
  }
  public IngressStatusFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.IngressStatus instance) {
    this.withLoadBalancer(instance.getLoadBalancer()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.LoadBalancerStatus loadBalancer;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public io.fabric8.kubernetes.api.model.LoadBalancerStatus getLoadBalancer() {
    return this.loadBalancer;
  }
  public A withLoadBalancer(io.fabric8.kubernetes.api.model.LoadBalancerStatus loadBalancer) {
    this.loadBalancer=loadBalancer; return (A) this;
  }
  public java.lang.Boolean hasLoadBalancer() {
    return this.loadBalancer != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressStatusFluentImpl that = (IngressStatusFluentImpl) o;
    if (loadBalancer != null ? !loadBalancer.equals(that.loadBalancer) :that.loadBalancer != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(loadBalancer,  additionalProperties,  super.hashCode());
  }
  
}

==> kubernetes-model-networking-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/IngressStatusFluentImpl.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LoadBalancerStatus;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public class IngressStatusFluentImpl<A extends io.fabric8.kubernetes.api.model.networking.v1.IngressStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.networking.v1.IngressStatusFluent<A>{
  public IngressStatusFluentImpl() {
  }
  public IngressStatusFluentImpl(io.fabric8.kubernetes.api.model.networking.v1.IngressStatus instance) {
    this.withLoadBalancer(instance.getLoadBalancer()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.LoadBalancerStatus loadBalancer;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public io.fabric8.kubernetes.api.model.LoadBalancerStatus getLoadBalancer() {
    return this.loadBalancer;
  }
  public A withLoadBalancer(io.fabric8.kubernetes.api.model.LoadBalancerStatus loadBalancer) {
    this.loadBalancer=loadBalancer; return (A) this;
  }
  public java.lang.Boolean hasLoadBalancer() {
    return this.loadBalancer != null;
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    IngressStatusFluentImpl that = (IngressStatusFluentImpl) o;
    if (loadBalancer != null ? !loadBalancer.equals(that.loadBalancer) :that.loadBalancer != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(loadBalancer,  additionalProperties,  super.hashCode());
  }
  
}
